/**
 * EasyBeans
 * Copyright (C) 2007-2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ENCBindingBuilder.java 3970 2008-09-26 12:50:34Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.war.impl.enc;

import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.impl.enc.AbsENCBindingBuilder;
import org.ow2.util.ee.metadata.common.impl.enc.ENCBindingException;
import org.ow2.util.ee.metadata.common.impl.enc.ENCBindingHolder;
import org.ow2.util.ee.metadata.war.api.IWarDeployableMetadata;

import java.util.Collection;

/**
 * Utility class that helps to build the ENC Binding by analyzing metadata.
 * @author Florent BENOIT
 */
public class ENCBindingBuilder extends AbsENCBindingBuilder {

    /**
     * All class metadata are kept by this object.
     */
    private IWarDeployableMetadata warArchiveMetadata = null;

    /**
     * Constructor used only by this class/subclasses.
     * @param warArchiveMetadata the given metadata to analyze.
     */
    protected ENCBindingBuilder(final IWarDeployableMetadata warArchiveMetadata) {
        super();
        this.warArchiveMetadata = warArchiveMetadata;
    }

    /**
     * @return list of metadata to analyze.
     */
    @Override
    protected Collection<? extends ICommonClassMetadata<?, ?, ?>> getClassMetadataCollection() {
        return warArchiveMetadata.getWarClassMetadataCollection();
    }

    /**
     * Found all ENC bindings from the given set of metadata.
     * @param warDeployableMetadata the given metadata to analyze.
     * @return object that contains all bindings found for the given set of
     *         classes.
     * @throws ENCBindingException if the analyze of the set of the metadata has
     *         failed.
     */
    public static ENCBindingHolder analyze(final IWarDeployableMetadata warDeployableMetadata) throws ENCBindingException {
        ENCBindingBuilder bindingBuilder = new ENCBindingBuilder(warDeployableMetadata);
        bindingBuilder.analyze();
        return bindingBuilder.getHolder();
    }

}
