/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: SpecificWarClassMetadata.java 3740 2008-07-25 14:43:14Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.war.impl.specific;

import org.ow2.util.ee.metadata.common.impl.specific.SpecificCommonClassMetadata;
import org.ow2.util.ee.metadata.war.api.IWarClassMetadata;
import org.ow2.util.ee.metadata.war.api.IWarDeployableMetadata;
import org.ow2.util.ee.metadata.war.api.IWarFieldMetadata;
import org.ow2.util.ee.metadata.war.api.IWarMethodMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificClassMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificFieldMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificMethodMetadata;

/**
 * You can extends this class to create a specific war class metadata.
 * @param <SC> specific class metadata
 * @param <SM> specific method metadata
 * @param <SF> specific field metadata
 * @author Gael Lalire
 */
public class SpecificWarClassMetadata<
    SC extends ISpecificClassMetadata<SC, SM, SF>,
    SM extends ISpecificMethodMetadata<SC, SM, SF>,
    SF extends ISpecificFieldMetadata<SC, SM, SF>>
        extends SpecificCommonClassMetadata<IWarClassMetadata, IWarMethodMetadata, IWarFieldMetadata, SC, SM, SF>
        implements IWarClassMetadata {

    /**
     * The standard war class metadata.
     */
    private IWarClassMetadata warClassMetadata;

    /**
     * Construct delegation.
     * @param warClassMetadata the standard war class metadata.
     */
    protected SpecificWarClassMetadata(final IWarClassMetadata warClassMetadata) {
        super(warClassMetadata);
        this.warClassMetadata = warClassMetadata;
    }

    /**
     * {@inheritDoc}
     */
    public IWarDeployableMetadata getWarDeployableMetadata() {
        return warClassMetadata.getWarDeployableMetadata();
    }

}
